@@ -1,6 +1,8 @@
+from cv2 import randShuffle
 from datasets import load_dataset
 import pandas as pd
 from keybert import KeyBERT
+from tqdm import tqdm
 
 
 def clean(keywords):
@@ -10,13 +12,16 @@ def clean(keywords):
 def clean_keywords(keywords):
   return clean(list(map(list, zip(*keywords)))[0])
 
-def make_keywords(df):
+def make_keywords(dataset):
   kw_model = KeyBERT()
-  for i in range(len(df)):
+  df = pd.DataFrame()
+  df["text"] = dataset["text"] or dataset["target"] or dataset["article"]
+  df["keywords"] = None
+  print(df)
+  for i in tqdm(range(len(df))):
     keyword = kw_model.extract_keywords(df['text'][i])
     clean = clean_keywords(keyword)
     df["keywords"][i] = clean
-    print(i)
   return df
 
 def make_dataset(dataset="common_gen", split="train"):
@@ -30,9 +35,7 @@ def make_dataset(dataset="common_gen", split="train"):
         return df
     else:
         dataset = load_dataset(dataset, split=split)
-        df = pd.DataFrame()
-        df["text"] = dataset["text"]
         df = make_keywords(df)
         return df
-  except:
-    return ValueError("Dataset not found")
+  except Exception as e:
+    raise e
